def cprint(x, color='green'):
    from termcolor import colored
    if color == 'info':
        color = 'green'
        x = 'INFO:' + str(x)
    if color == 'debug':
        color = 'red'
        x = 'DEBUG:' + str(x)
        
    print(colored(x, color))

def lcprint(*arr, color='green'):
    x = ':: '.join([str(i) for i in arr])
    from termcolor import colored
    if color.lower() == 'info':
        color = 'green'
        x = 'INFO:' + str(x)
    if color.lower() == 'debug':
        color = 'red'
        x = 'DEBUG:' + str(x)
        
    print(colored(x, color))


import numpy as np
import torch
import random

def print_shape(*a):
    for t in a:
        print(t.shape)
        
def seed_everything(seed=42):
    np.random.seed(seed)
    torch.manual_seed(seed)
    random.seed(seed)

    if torch.cuda.is_available():
        torch.cuda.manual_seed(seed)